Architecture
============

Chewie contains two state machines that host the state of users as they perform authentication.

EAPOL State Machine
...................

.. image:: eap_state_machine.png


Mac Authentication Bypass Machine
.......................................

.. image:: mab_state_machine.png
